Learn R Programming

MultiDiscreteRNG (version 0.1.0)

GetGpoisPMF: Get probability mass function of generalized Poisson distribution

Description

This function returns a table of the probability mass function of generalized Poisson distribution.

Usage

GetGpoisPMF(p, theta, lambda, details = FALSE)

Value

A named numeric vector containing the generalized Poisson PMF values over the computed support (names correspond to support points \(x = 0,1,2,\dots\)). Very small probabilities (below 1e-10) are removed.

Arguments

p

Probability level(s) used to determine how far to compute the support (the PMF is generated until the CDF exceeds max(p)).

theta

Theta parameter(s) for the generalized Poisson distribution.

lambda

Lambda parameter(s) for the generalized Poisson distribution.

details

Logical; if TRUE, additional computation information is printed.

Examples

Run this code
# PMF values computed until the CDF exceeds p = 1
gpd_pmf <- GetGpoisPMF(p = 1, theta = 0.2, lambda = 0.3)
gpd_pmf

Run the code above in your browser using DataLab