Learn R Programming

MultiDiscreteRNG (version 0.1.0)

QuantileGpois: Compute the quantile function of the generalized Poisson distribution

Description

This function evaluates the generalized Poisson quantile \(Q(p)\) by incrementally constructing the PMF and CDF from \(x=0\) upward until the CDF exceeds the largest requested probability in p. The returned quantile(s) are the smallest integer \(x\) such that \(P(X \le x) \ge p\).

Usage

QuantileGpois(p, theta, lambda, details = FALSE)

Value

An integer vector of generalized Poisson quantiles corresponding to p.

Arguments

p

vector of probabilities

theta

vector of theta

lambda

vector of lambda

details

A logical flag to return the computational details

Examples

Run this code
QuantileGpois(p = 0.95, theta = 2, lambda = 0.1)

Run the code above in your browser using DataLab