Learn R Programming

MultiDiscreteRNG (version 0.1.0)

validation.NBparameters: Validate if the input negative binomial parameters are within feasible range

Description

Validate if the input negative binomial parameters are within feasible range

Usage

validation.NBparameters(NB.r.vec, NB.prob.vec)

Value

No return values; called it to check parameter inputs

Arguments

NB.r.vec

Vector of number of trials parameters

NB.prob.vec

Vector of probabilities

Examples

Run this code
validation.NBparameters(NB.r.vec = c(10, 15), NB.prob.vec = c(0.7, 0.5))

Run the code above in your browser using DataLab