GetGpoisPMF: Get probability mass function of generalized Poisson distribution
Description
This function returns a table of the probability mass function of generalized Poisson distribution.
Usage
GetGpoisPMF(p, theta, lambda, details = FALSE)
Value
A named numeric vector containing the generalized Poisson PMF values over the computed
support (names correspond to support points \(x = 0,1,2,\dots\)). Very small probabilities
(below 1e-10) are removed.
Arguments
p
Probability level(s) used to determine how far to compute the support (the PMF is
generated until the CDF exceeds max(p)).
theta
Theta parameter(s) for the generalized Poisson distribution.
lambda
Lambda parameter(s) for the generalized Poisson distribution.
details
Logical; if TRUE, additional computation information is printed.