calc.bin.prob.NB: Collapse discrete negative binomial outcomes to binary variables
Description
This function implements Step 1 of the algorithm. It collapses each discrete
outcome from the negative binomial distribution into a binary
probability and determines a dichotomous threshold for each variable.
Usage
calc.bin.prob.NB(NB.r.vec, NB.prob.vec)
Value
vector of binary probability, dichotomous threshold