generate.binaryVar: Generate multivariate Binary data using the Emrich and Piedmonte (1991) approach
Approach
Description
Generate multivariate Binary data using the Emrich and Piedmonte (1991) approach
Approach
Usage
generate.binaryVar(nObs, prop.vec.bin, corr.mat)
Value
multivariate Binary Data
Arguments
- nObs
number of observations
- prop.vec.bin
probability of binary variables in a vector
- corr.mat
Correlation matrix